@@ -1,11 +1,18 @@
 import itertools
-import boto3
-from botocore.exceptions import ClientError
+
 from smart_open import smart_open_lib
 
-from .blob import to_file_key, to_dir_key, PureBlobPath, _SkeletonBlobPath
-from .uri import _UriFlavour
-from .common import PurePath, Path
+try:
+    import boto3
+    from botocore.exceptions import ClientError
+except ImportError:
+    MISSING_DEPS = True
+else:
+    MISSING_DEPS = False
+
+from paaaaath.blob import PureBlobPath, _SkeletonBlobPath, to_dir_key, to_file_key
+from paaaaath.common import Path, PurePath
+from paaaaath.uri import _UriFlavour
 
 
 class _S3Flavour(_UriFlavour):
@@ -15,13 +22,13 @@ class _S3Flavour(_UriFlavour):
 _s3_flavour = _S3Flavour()
 
 
-@PurePath.register
+@PurePath.register()
 class PureS3Path(PureBlobPath):
     _flavour = _s3_flavour
     __slots__ = ()
 
 
-@Path.register
+@Path.register(MISSING_DEPS)
 class S3Path(_SkeletonBlobPath, PureS3Path):
     __slots__ = ()
 
